'use client';

import * as React from 'react';
import * as AvatarPrimitive from '@radix-ui/react-avatar';
import { User } from 'lucide-react';

import { cn } from '@/lib/utils';

function Avatar({
  className,
  ...props
}: React.ComponentProps<typeof AvatarPrimitive.Root>) {
  return (
    <AvatarPrimitive.Root
      data-slot='avatar'
      className={cn(
        'relative flex size-8 shrink-0 overflow-hidden rounded-full',
        className,
      )}
      {...props}
    />
  );
}

type BasedAvatarImageProps = React.ComponentProps<typeof AvatarPrimitive.Image> & {
  fullName: string;
};

function BasedAvatarImage({
  fullName,
  className,
  ...props
}: BasedAvatarImageProps) {
  return (
    <AvatarPrimitive.Image
      data-slot='avatar-image'
      className={cn('aspect-square size-full', className)}
      alt={fullName.split(' ').map((n) => n[0]).join('').toUpperCase()}
      {...props}
    />
  );
}

function AvatarImage({
  className,
  ...props
}: React.ComponentProps<typeof AvatarPrimitive.Image>) {
  return (
    <AvatarPrimitive.Image
      data-slot='avatar-image'
      className={cn('aspect-square size-full', className)}
      {...props}
    />
  );
}

type BasedAvatarFallbackProps =
React.ComponentProps<typeof AvatarPrimitive.Fallback> & {
  fullName?: string | null;
};

function BasedAvatarFallback({
  fullName = null,
  className,
  ...props
}: BasedAvatarFallbackProps) {
  return (
    <AvatarPrimitive.Fallback
      data-slot='avatar-fallback'
      className={cn(
        'bg-muted flex size-full items-center justify-center rounded-full',
        className,
      )}
      {...props}
    >
      {fullName ? (
        fullName
          .split(' ')
          .map((n) => n[0])
          .join('')
          .toUpperCase()
      ) : (
        <User size={64} />
      )}
    </AvatarPrimitive.Fallback>
  );
}

function AvatarFallback({
  className,
  ...props
}: React.ComponentProps<typeof AvatarPrimitive.Fallback & {fullName: string}>) {
  return (
    <AvatarPrimitive.Fallback
      data-slot='avatar-fallback'
      className={cn(
        'bg-muted flex size-full items-center justify-center rounded-full',
        className,
      )}
      {...props}
    />
  );
}

export { Avatar, AvatarImage, BasedAvatarImage, AvatarFallback, BasedAvatarFallback };
